@@ -336,7 +336,7 @@ def _legacy_upload(config, pconn, tar_file, content_type, collection_duration=No
                 logger.info("Successfully uploaded report for %s.", msg_name)
             if config.register:
                 # direct to console after register + upload
-                logger.info('View the Red Hat Insights console at https://cloud.redhat.com/insights/')
+                logger.info('View the Red Hat Insights console at https://console.redhat.com/insights/')
             break
 
         elif upload.status_code in (412, 413):
@@ -370,7 +370,7 @@ def upload(config, pconn, tar_file, content_type, collection_duration=None):
             logger.info("Successfully uploaded report for %s.", msg_name)
             if config.register:
                 # direct to console after register + upload
-                logger.info('View the Red Hat Insights console at https://cloud.redhat.com/insights/')
+                logger.info('View the Red Hat Insights console at https://console.redhat.com/insights/')
             return
         elif upload.status_code in (413, 415):
             pconn.handle_fail_rcs(upload)
