@@ -113,6 +113,8 @@ rhel_release_map = {
     "4.18.0-240": "8.3",
     "4.18.0-305": "8.4",
     "4.18.0-348": "8.5",
+    "4.18.0-372": "8.6",
+    "5.14.0-70": "9.0",
 }
 
 release_to_kernel_map = dict((v, k) for k, v in rhel_release_map.items())
@@ -553,7 +555,14 @@ class Uname(CommandParser):
 
     @property
     def release_tuple(self):
-        return tuple(map(int, self.data["rhel_release"]))
+        rel = []
+        for v in self.data['rhel_release']:
+            try:
+                rel.append(int(v))
+            except ValueError:
+                rel.append(v)
+
+        return tuple(rel)
 
     @property
     def redhat_release(self):
