@@ -21,6 +21,7 @@ class Specs(SpecSet):
     awx_manage_print_settings = RegistryPoint()
     azure_instance_type = RegistryPoint()
     azure_instance_plan = RegistryPoint()
+    bdi_read_ahead_kb = RegistryPoint(multi_output=True)
     bios_uuid = RegistryPoint()
     blkid = RegistryPoint()
     bond = RegistryPoint(multi_output=True)
@@ -73,6 +74,7 @@ class Specs(SpecSet):
     cni_podman_bridge_conf = RegistryPoint()
     cobbler_modules_conf = RegistryPoint()
     cobbler_settings = RegistryPoint()
+    containers_policy = RegistryPoint()
     corosync = RegistryPoint()
     corosync_cmapctl = RegistryPoint(multi_output=True)
     corosync_conf = RegistryPoint()
@@ -143,7 +145,7 @@ class Specs(SpecSet):
     doveconf = RegistryPoint(filterable=True)
     dracut_kdump_capture_service = RegistryPoint()
     dse_ldif = RegistryPoint(multi_output=True, filterable=True)
-    du_dirs = RegistryPoint(multi_output=True)
+    du_dirs = RegistryPoint(multi_output=True, filterable=True)
     dumpe2fs_h = RegistryPoint(multi_output=True)
     engine_config_all = RegistryPoint()
     engine_db_query_vdsm_version = RegistryPoint()
@@ -286,6 +288,7 @@ class Specs(SpecSet):
     kdump_conf = RegistryPoint()
     kerberos_kdc_log = RegistryPoint(filterable=True)
     kernel_config = RegistryPoint(multi_output=True, filterable=True)
+    kernel_crash_kexec_post_notifiers = RegistryPoint()
     kexec_crash_loaded = RegistryPoint()
     kexec_crash_size = RegistryPoint()
     keystone_conf = RegistryPoint()
@@ -386,6 +389,7 @@ class Specs(SpecSet):
     mokutil_sbstate = RegistryPoint()
     mongod_conf = RegistryPoint(multi_output=True, filterable=True)
     mount = RegistryPoint()
+    mountinfo = RegistryPoint()
     mounts = RegistryPoint()
     mssql_conf = RegistryPoint()
     mssql_api_assessment = RegistryPoint()
@@ -424,6 +428,7 @@ class Specs(SpecSet):
     nfs_exports_d = RegistryPoint(multi_output=True)
     nfs_exports = RegistryPoint()
     nginx_conf = RegistryPoint(multi_output=True)
+    nginx_error_log = RegistryPoint(filterable=True)
     nginx_ssl_cert_enddate = RegistryPoint(multi_output=True)
     nmcli_conn_show = RegistryPoint()
     nmcli_dev_show = RegistryPoint()
@@ -518,6 +523,7 @@ class Specs(SpecSet):
     postgresql_conf = RegistryPoint()
     postgresql_log = RegistryPoint(multi_output=True, filterable=True)
     prev_uploader_log = RegistryPoint()
+    proc_keys = RegistryPoint()
     proc_netstat = RegistryPoint()
     proc_slabinfo = RegistryPoint()
     proc_snmp_ipv4 = RegistryPoint()
@@ -540,6 +546,7 @@ class Specs(SpecSet):
     qemu_conf = RegistryPoint()
     qemu_xml = RegistryPoint(multi_output=True)
     ql2xmaxlun = RegistryPoint()
+    ql2xmqsupport = RegistryPoint()
     qpid_stat_g = RegistryPoint()
     qpid_stat_q = RegistryPoint()
     qpid_stat_u = RegistryPoint()
@@ -663,6 +670,7 @@ class Specs(SpecSet):
     sysconfig_memcached = RegistryPoint()
     sysconfig_mongod = RegistryPoint(multi_output=True)
     sysconfig_network = RegistryPoint()
+    sysconfig_nfs = RegistryPoint()
     sysconfig_ntpd = RegistryPoint()
     sysconfig_oracleasm = RegistryPoint()
     sysconfig_prelink = RegistryPoint()
