@@ -106,7 +106,7 @@ class InsightsArchiveSpecs(Specs):
     ipv4_neigh = simple_file("insights_commands/ip_-4_neighbor_show_nud_all")
     ipv6_neigh = simple_file("insights_commands/ip_-6_neighbor_show_nud_all")
     iscsiadm_m_session = simple_file("insights_commands/iscsiadm_-m_session")
-    keystone_crontab = simple_file("insights_commands/crontab_-l_-u_keystone")
+    keystone_crontab = first_file(["insights_commands/crontab_-l_-u_keystone", "var/spool/cron/keystone"])
     kpatch_list = simple_file("insights_commands/kpatch_list")
     localtime = simple_file("insights_commands/file_-L_.etc.localtime")
     losetup = simple_file("insights_commands/losetup_-l")
@@ -182,7 +182,7 @@ class InsightsArchiveSpecs(Specs):
     netstat_s = simple_file("insights_commands/netstat_-s")
     nmcli_conn_show = simple_file("insights_commands/nmcli_conn_show")
     nmcli_dev_show = simple_file("insights_commands/nmcli_dev_show")
-    nova_crontab = simple_file("insights_commands/crontab_-l_-u_nova")
+    nova_crontab = first_file(["insights_commands/crontab_-l_-u_nova", "var/spool/cron/nova"])
     nova_uid = simple_file("insights_commands/id_-u_nova")
     ntpq_leap = simple_file("insights_commands/ntpq_-c_rv_0_leap")
     ntpq_pn = simple_file("insights_commands/ntpq_-pn")
